# ephor-server-ti-client
Collaborative AI

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.3.0
- Package version: 1.0.0
- Generator version: 7.9.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import ephor_server_ti_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import ephor_server_ti_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import ephor_server_ti_client
from ephor_server_ti_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = ephor_server_ti_client.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: APIKeyHeader
configuration.api_key['APIKeyHeader'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['APIKeyHeader'] = 'Bearer'


# Enter a context with an instance of the API client
with ephor_server_ti_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = ephor_server_ti_client.AccountApi(api_client)
    command_id = 'command_id_example' # str | 

    try:
        # Delete Command
        api_response = api_instance.delete_command_api_v1_account_commands_command_id_delete(command_id)
        print("The response of AccountApi->delete_command_api_v1_account_commands_command_id_delete:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AccountApi->delete_command_api_v1_account_commands_command_id_delete: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccountApi* | [**delete_command_api_v1_account_commands_command_id_delete**](docs/AccountApi.md#delete_command_api_v1_account_commands_command_id_delete) | **DELETE** /api/v1/account/commands/{command_id} | Delete Command
*AccountApi* | [**delete_google_integration_api_v1_account_oauth_google_delete**](docs/AccountApi.md#delete_google_integration_api_v1_account_oauth_google_delete) | **DELETE** /api/v1/account/oauth/google | Delete Google Integration
*AccountApi* | [**generate_api_key_api_v1_account_api_key_post**](docs/AccountApi.md#generate_api_key_api_v1_account_api_key_post) | **POST** /api/v1/account/api-key | Generate Api Key
*AccountApi* | [**get_account_id_api_v1_account_id_get**](docs/AccountApi.md#get_account_id_api_v1_account_id_get) | **GET** /api/v1/account/id | Get Account Id
*AccountApi* | [**get_active_api_keys_route_api_v1_account_api_key_get**](docs/AccountApi.md#get_active_api_keys_route_api_v1_account_api_key_get) | **GET** /api/v1/account/api-key | Get Active Api Keys Route
*AccountApi* | [**get_available_commands_api_v1_account_commands_get**](docs/AccountApi.md#get_available_commands_api_v1_account_commands_get) | **GET** /api/v1/account/commands | Get Available Commands
*AccountApi* | [**get_clerk_google_token_api_v1_account_clerk_google_get**](docs/AccountApi.md#get_clerk_google_token_api_v1_account_clerk_google_get) | **GET** /api/v1/account/clerk/google | Get Clerk Google Token
*AccountApi* | [**get_command_api_v1_account_commands_command_id_get**](docs/AccountApi.md#get_command_api_v1_account_commands_command_id_get) | **GET** /api/v1/account/commands/{command_id} | Get Command
*AccountApi* | [**get_current_profile_api_v1_account_profile_get**](docs/AccountApi.md#get_current_profile_api_v1_account_profile_get) | **GET** /api/v1/account/profile | Get Current Profile
*AccountApi* | [**get_google_integration_api_v1_account_oauth_google_get**](docs/AccountApi.md#get_google_integration_api_v1_account_oauth_google_get) | **GET** /api/v1/account/oauth/google | Get Google Integration
*AccountApi* | [**get_google_integration_status_api_v1_account_oauth_google_status_get**](docs/AccountApi.md#get_google_integration_status_api_v1_account_oauth_google_status_get) | **GET** /api/v1/account/oauth/google/status | Get Google Integration Status
*AccountApi* | [**get_profile_api_v1_account_profile_account_id_get**](docs/AccountApi.md#get_profile_api_v1_account_profile_account_id_get) | **GET** /api/v1/account/profile/{account_id} | Get Profile
*AccountApi* | [**get_profile_summary_api_v1_account_profile_summary_get**](docs/AccountApi.md#get_profile_summary_api_v1_account_profile_summary_get) | **GET** /api/v1/account/profile/summary | Get Profile Summary
*AccountApi* | [**get_public_profile_api_v1_account_public_profile_account_id_get**](docs/AccountApi.md#get_public_profile_api_v1_account_public_profile_account_id_get) | **GET** /api/v1/account/public-profile/{account_id} | Get Public Profile
*AccountApi* | [**get_user_activities_api_v1_account_profile_activities_get**](docs/AccountApi.md#get_user_activities_api_v1_account_profile_activities_get) | **GET** /api/v1/account/profile-activities | Get User Activities
*AccountApi* | [**oauth_google_authorize_api_v1_account_oauth_google_authorize_get**](docs/AccountApi.md#oauth_google_authorize_api_v1_account_oauth_google_authorize_get) | **GET** /api/v1/account/oauth/google/authorize | Oauth Google Authorize
*AccountApi* | [**oauth_google_callback_api_v1_account_oauth_google_callback_get**](docs/AccountApi.md#oauth_google_callback_api_v1_account_oauth_google_callback_get) | **GET** /api/v1/account/oauth/google/callback | Oauth Google Callback
*AccountApi* | [**revoke_api_key_api_v1_account_api_key_delete**](docs/AccountApi.md#revoke_api_key_api_v1_account_api_key_delete) | **DELETE** /api/v1/account/api-key | Revoke Api Key
*AccountApi* | [**search_users_endpoint_api_v1_account_search_get**](docs/AccountApi.md#search_users_endpoint_api_v1_account_search_get) | **GET** /api/v1/account/search | Search Users Endpoint
*AccountApi* | [**update_integrations_api_v1_account_integrations_put**](docs/AccountApi.md#update_integrations_api_v1_account_integrations_put) | **PUT** /api/v1/account/integrations | Update Integrations
*AccountApi* | [**upsert_command_api_v1_account_commands_put**](docs/AccountApi.md#upsert_command_api_v1_account_commands_put) | **PUT** /api/v1/account/commands | Upsert Command
*BackgroundServicesApi* | [**refresh_folder_api_v1_background_services_refresh_folder_post**](docs/BackgroundServicesApi.md#refresh_folder_api_v1_background_services_refresh_folder_post) | **POST** /api/v1/background-services/refresh-folder | Refresh Folder
*ChannelsApi* | [**create_channel_api_v1_projects_project_id_channels_post_0**](docs/ChannelsApi.md#create_channel_api_v1_projects_project_id_channels_post_0) | **POST** /api/v1/projects/{project_id}/channels | Create a new channel
*ChannelsApi* | [**delete_channel_api_v1_projects_project_id_channels_channel_id_delete_0**](docs/ChannelsApi.md#delete_channel_api_v1_projects_project_id_channels_channel_id_delete_0) | **DELETE** /api/v1/projects/{project_id}/channels/{channel_id} | Delete a channel by ID
*ChannelsApi* | [**fork_channel_api_v1_projects_project_id_channels_channel_id_fork_post_0**](docs/ChannelsApi.md#fork_channel_api_v1_projects_project_id_channels_channel_id_fork_post_0) | **POST** /api/v1/projects/{project_id}/channels/{channel_id}/fork | Fork a channel
*ChannelsApi* | [**get_channel_api_v1_projects_project_id_channels_channel_id_get_0**](docs/ChannelsApi.md#get_channel_api_v1_projects_project_id_channels_channel_id_get_0) | **GET** /api/v1/projects/{project_id}/channels/{channel_id} | Get a channel by ID
*ChannelsApi* | [**get_channel_messages_api_v1_projects_project_id_channels_channel_id_messages_get_0**](docs/ChannelsApi.md#get_channel_messages_api_v1_projects_project_id_channels_channel_id_messages_get_0) | **GET** /api/v1/projects/{project_id}/channels/{channel_id}/messages | Get messages for a channel
*ChannelsApi* | [**get_channels_api_v1_projects_project_id_channels_get_0**](docs/ChannelsApi.md#get_channels_api_v1_projects_project_id_channels_get_0) | **GET** /api/v1/projects/{project_id}/channels | Get channels for a project
*ChannelsApi* | [**update_channel_name_api_v1_projects_project_id_channels_channel_id_patch_0**](docs/ChannelsApi.md#update_channel_name_api_v1_projects_project_id_channels_channel_id_patch_0) | **PATCH** /api/v1/projects/{project_id}/channels/{channel_id} | Update the channel name
*ConversationsApi* | [**create_conversation_api_v1_conversations_post**](docs/ConversationsApi.md#create_conversation_api_v1_conversations_post) | **POST** /api/v1/conversations/ | Create Conversation
*ConversationsApi* | [**delete_attachment_api_v1_conversations_attachments_attachment_id_delete**](docs/ConversationsApi.md#delete_attachment_api_v1_conversations_attachments_attachment_id_delete) | **DELETE** /api/v1/conversations/attachments/{attachment_id} | Delete Attachment
*ConversationsApi* | [**delete_conversation_api_v1_conversations_conversation_id_delete**](docs/ConversationsApi.md#delete_conversation_api_v1_conversations_conversation_id_delete) | **DELETE** /api/v1/conversations/{conversation_id} | Delete Conversation
*ConversationsApi* | [**get_attachment_api_v1_conversations_attachments_attachment_id_get**](docs/ConversationsApi.md#get_attachment_api_v1_conversations_attachments_attachment_id_get) | **GET** /api/v1/conversations/attachments/{attachment_id} | Get Attachment
*ConversationsApi* | [**get_conversation_api_v1_conversations_conversation_id_get**](docs/ConversationsApi.md#get_conversation_api_v1_conversations_conversation_id_get) | **GET** /api/v1/conversations/{conversation_id} | Get Conversation
*ConversationsApi* | [**get_conversations_api_v1_conversations_get**](docs/ConversationsApi.md#get_conversations_api_v1_conversations_get) | **GET** /api/v1/conversations/ | Get Conversations
*ConversationsApi* | [**get_message_models_api_v1_conversations_conversation_id_messages_message_id_models_get**](docs/ConversationsApi.md#get_message_models_api_v1_conversations_conversation_id_messages_message_id_models_get) | **GET** /api/v1/conversations/{conversation_id}/messages/{message_id}/models | Get Message Models
*ConversationsApi* | [**update_conversation_api_v1_conversations_conversation_id_put**](docs/ConversationsApi.md#update_conversation_api_v1_conversations_conversation_id_put) | **PUT** /api/v1/conversations/{conversation_id} | Update Conversation
*ConversationsApi* | [**upload_attachment_api_v1_conversations_attachments_post**](docs/ConversationsApi.md#upload_attachment_api_v1_conversations_attachments_post) | **POST** /api/v1/conversations/attachments | Upload Attachment
*CrawlApi* | [**add_webcrawling_request_api_v1_crawl_new_post**](docs/CrawlApi.md#add_webcrawling_request_api_v1_crawl_new_post) | **POST** /api/v1/crawl/new | Add Webcrawling Request
*FeedbackApi* | [**create_feedback_api_v1_feedback_post**](docs/FeedbackApi.md#create_feedback_api_v1_feedback_post) | **POST** /api/v1/feedback/ | Create Feedback
*FeedbackApi* | [**delete_feedback_api_v1_feedback_feedback_id_delete**](docs/FeedbackApi.md#delete_feedback_api_v1_feedback_feedback_id_delete) | **DELETE** /api/v1/feedback/{feedback_id} | Delete Feedback
*FeedbackApi* | [**get_message_feedback_api_v1_feedback_message_id_get**](docs/FeedbackApi.md#get_message_feedback_api_v1_feedback_message_id_get) | **GET** /api/v1/feedback/{message_id} | Get Message Feedback
*InteractApi* | [**compare_responses_api_v1_interact_compare_post**](docs/InteractApi.md#compare_responses_api_v1_interact_compare_post) | **POST** /api/v1/interact/compare | Compare Responses
*InteractApi* | [**create_or_connect_sandbox_api_v1_interact_tasks_artifacts_sandbox_post**](docs/InteractApi.md#create_or_connect_sandbox_api_v1_interact_tasks_artifacts_sandbox_post) | **POST** /api/v1/interact/tasks/artifacts/sandbox | Create Or Connect Sandbox
*InteractApi* | [**execute_code_api_v1_interact_tasks_artifacts_execute_post**](docs/InteractApi.md#execute_code_api_v1_interact_tasks_artifacts_execute_post) | **POST** /api/v1/interact/tasks/artifacts/execute | Execute Code
*InteractApi* | [**generate_react_api_v1_interact_tasks_artifacts_generate_react_post**](docs/InteractApi.md#generate_react_api_v1_interact_tasks_artifacts_generate_react_post) | **POST** /api/v1/interact/tasks/artifacts/generate/react | Generate React
*InteractApi* | [**generate_streamlit_api_v1_interact_tasks_artifacts_generate_streamlit_post**](docs/InteractApi.md#generate_streamlit_api_v1_interact_tasks_artifacts_generate_streamlit_post) | **POST** /api/v1/interact/tasks/artifacts/generate/streamlit | Generate Streamlit
*InteractApi* | [**interact_api_v1_interact_post**](docs/InteractApi.md#interact_api_v1_interact_post) | **POST** /api/v1/interact/ | Interact
*InteractApi* | [**interact_stream_api_v1_interact_stream_post**](docs/InteractApi.md#interact_stream_api_v1_interact_stream_post) | **POST** /api/v1/interact/stream | Interact Stream
*InteractApi* | [**query_api_v1_interact_query_post**](docs/InteractApi.md#query_api_v1_interact_query_post) | **POST** /api/v1/interact/query | Query
*InteractApi* | [**text_qna_api_v1_interact_tasks_text_post**](docs/InteractApi.md#text_qna_api_v1_interact_tasks_text_post) | **POST** /api/v1/interact/tasks/text/ | Text Qna
*LibraryApi* | [**delete_library_item_api_v1_library_library_id_index_reference_delete**](docs/LibraryApi.md#delete_library_item_api_v1_library_library_id_index_reference_delete) | **DELETE** /api/v1/library/{library_id}/{index_reference} | Delete Library Item
*LibraryApi* | [**delete_manifest_item_api_v1_library_library_id_index_reference_item_item_id_delete**](docs/LibraryApi.md#delete_manifest_item_api_v1_library_library_id_index_reference_item_item_id_delete) | **DELETE** /api/v1/library/{library_id}/{index_reference}/item/{item_id} | Delete Manifest Item
*LibraryApi* | [**get_indexing_stats_api_v1_library_ingest_stats_namespace_get**](docs/LibraryApi.md#get_indexing_stats_api_v1_library_ingest_stats_namespace_get) | **GET** /api/v1/library/ingest/stats/{namespace} | Get Indexing Stats
*LibraryApi* | [**get_library_api_v1_library_library_id_get**](docs/LibraryApi.md#get_library_api_v1_library_library_id_get) | **GET** /api/v1/library/{library_id} | Get Library
*LibraryApi* | [**get_library_item_api_v1_library_folder_index_reference_get**](docs/LibraryApi.md#get_library_item_api_v1_library_folder_index_reference_get) | **GET** /api/v1/library/folder/{index_reference} | Get Library Item
*LibraryApi* | [**ingest_documents_api_v1_library_ingest_post**](docs/LibraryApi.md#ingest_documents_api_v1_library_ingest_post) | **POST** /api/v1/library/ingest/ | Ingest Documents
*LibraryApi* | [**ingest_local_file_api_v1_library_ingest_local_file_post**](docs/LibraryApi.md#ingest_local_file_api_v1_library_ingest_local_file_post) | **POST** /api/v1/library/ingest/local-file | Ingest Local File
*LibraryApi* | [**ingest_private_chats_api_v1_library_privatechats_project_id_library_id_post**](docs/LibraryApi.md#ingest_private_chats_api_v1_library_privatechats_project_id_library_id_post) | **POST** /api/v1/library/privatechats/{project_id}/{library_id} | Ingest Private Chats
*LibraryApi* | [**ingest_shared_chats_api_v1_library_sharedchats_project_id_library_id_post**](docs/LibraryApi.md#ingest_shared_chats_api_v1_library_sharedchats_project_id_library_id_post) | **POST** /api/v1/library/sharedchats/{project_id}/{library_id} | Ingest Shared Chats
*LibraryApi* | [**ingest_video_api_v1_library_ingest_video_post**](docs/LibraryApi.md#ingest_video_api_v1_library_ingest_video_post) | **POST** /api/v1/library/ingest/video | Ingest Video
*LibraryApi* | [**library_root_api_v1_library_get**](docs/LibraryApi.md#library_root_api_v1_library_get) | **GET** /api/v1/library/ | Library Root
*LibraryApi* | [**refresh_library_item_api_v1_library_index_reference_refresh_post**](docs/LibraryApi.md#refresh_library_item_api_v1_library_index_reference_refresh_post) | **POST** /api/v1/library/{index_reference}/refresh | Refresh Library Item
*LibraryApi* | [**refresh_workflowy_nodes_api_v1_library_ingest_workflowy_refresh_post**](docs/LibraryApi.md#refresh_workflowy_nodes_api_v1_library_ingest_workflowy_refresh_post) | **POST** /api/v1/library/ingest/workflowy/refresh | Refresh Workflowy Nodes
*LibraryApi* | [**retrieve_documents_api_v1_library_retrieve_post**](docs/LibraryApi.md#retrieve_documents_api_v1_library_retrieve_post) | **POST** /api/v1/library/retrieve/ | Retrieve Documents
*LibraryApi* | [**scrape_and_ingest_workflowy_api_v1_library_ingest_workflowy_post**](docs/LibraryApi.md#scrape_and_ingest_workflowy_api_v1_library_ingest_workflowy_post) | **POST** /api/v1/library/ingest/workflowy | Scrape And Ingest Workflowy
*LibraryApi* | [**update_manifest_item_api_v1_library_index_reference_item_id_patch**](docs/LibraryApi.md#update_manifest_item_api_v1_library_index_reference_item_id_patch) | **PATCH** /api/v1/library/{index_reference}/{item_id} | Update Manifest Item
*ProjectsApi* | [**accept_invitation_api_v1_projects_invite_email_invite_id_post**](docs/ProjectsApi.md#accept_invitation_api_v1_projects_invite_email_invite_id_post) | **POST** /api/v1/projects/invite/email/{invite_id} | Accept Invitation
*ProjectsApi* | [**add_comment_api_v1_projects_project_id_comments_post**](docs/ProjectsApi.md#add_comment_api_v1_projects_project_id_comments_post) | **POST** /api/v1/projects/{project_id}/comments | Add Comment
*ProjectsApi* | [**add_user_to_project_api_v1_projects_project_id_add_user_email_get**](docs/ProjectsApi.md#add_user_to_project_api_v1_projects_project_id_add_user_email_get) | **GET** /api/v1/projects/{project_id}/add-user/{email} | Add User To Project
*ProjectsApi* | [**clean_up_projects_api_v1_projects_clean_up_get**](docs/ProjectsApi.md#clean_up_projects_api_v1_projects_clean_up_get) | **GET** /api/v1/projects/clean_up | Clean Up Projects
*ProjectsApi* | [**create_channel_api_v1_projects_project_id_channels_post**](docs/ProjectsApi.md#create_channel_api_v1_projects_project_id_channels_post) | **POST** /api/v1/projects/{project_id}/channels | Create a new channel
*ProjectsApi* | [**create_project_api_v1_projects_post**](docs/ProjectsApi.md#create_project_api_v1_projects_post) | **POST** /api/v1/projects/ | Create Project
*ProjectsApi* | [**delete_channel_api_v1_projects_project_id_channels_channel_id_delete**](docs/ProjectsApi.md#delete_channel_api_v1_projects_project_id_channels_channel_id_delete) | **DELETE** /api/v1/projects/{project_id}/channels/{channel_id} | Delete a channel by ID
*ProjectsApi* | [**delete_project_api_v1_projects_project_id_delete**](docs/ProjectsApi.md#delete_project_api_v1_projects_project_id_delete) | **DELETE** /api/v1/projects/{project_id} | Delete Project
*ProjectsApi* | [**edit_channel_api_v1_projects_project_id_channels_channel_id_put**](docs/ProjectsApi.md#edit_channel_api_v1_projects_project_id_channels_channel_id_put) | **PUT** /api/v1/projects/{project_id}/channels/{channel_id} | Edit Channel
*ProjectsApi* | [**edit_project_api_v1_projects_project_id_put**](docs/ProjectsApi.md#edit_project_api_v1_projects_project_id_put) | **PUT** /api/v1/projects/{project_id} | Edit Project
*ProjectsApi* | [**export_data_api_v1_projects_project_id_export_post**](docs/ProjectsApi.md#export_data_api_v1_projects_project_id_export_post) | **POST** /api/v1/projects/{project_id}/export | Export Data
*ProjectsApi* | [**fork_channel_api_v1_projects_project_id_channels_channel_id_fork_post**](docs/ProjectsApi.md#fork_channel_api_v1_projects_project_id_channels_channel_id_fork_post) | **POST** /api/v1/projects/{project_id}/channels/{channel_id}/fork | Fork a channel
*ProjectsApi* | [**generate_guided_queries_api_v1_projects_project_id_generate_queries_post**](docs/ProjectsApi.md#generate_guided_queries_api_v1_projects_project_id_generate_queries_post) | **POST** /api/v1/projects/{project_id}/generate_queries | Generate Guided Queries
*ProjectsApi* | [**get_channel_api_v1_projects_project_id_channels_channel_id_get**](docs/ProjectsApi.md#get_channel_api_v1_projects_project_id_channels_channel_id_get) | **GET** /api/v1/projects/{project_id}/channels/{channel_id} | Get a channel by ID
*ProjectsApi* | [**get_channel_messages_api_v1_projects_project_id_channels_channel_id_messages_get**](docs/ProjectsApi.md#get_channel_messages_api_v1_projects_project_id_channels_channel_id_messages_get) | **GET** /api/v1/projects/{project_id}/channels/{channel_id}/messages | Get messages for a channel
*ProjectsApi* | [**get_channels_api_v1_projects_project_id_channels_get**](docs/ProjectsApi.md#get_channels_api_v1_projects_project_id_channels_get) | **GET** /api/v1/projects/{project_id}/channels | Get channels for a project
*ProjectsApi* | [**get_expert_comments_api_v1_projects_project_id_channels_channel_id_messages_message_id_expert_comments_get**](docs/ProjectsApi.md#get_expert_comments_api_v1_projects_project_id_channels_channel_id_messages_message_id_expert_comments_get) | **GET** /api/v1/projects/{project_id}/channels/{channel_id}/messages/{message_id}/expert-comments | Get Expert Comments
*ProjectsApi* | [**get_project_api_v1_projects_project_id_get**](docs/ProjectsApi.md#get_project_api_v1_projects_project_id_get) | **GET** /api/v1/projects/{project_id} | Get Project
*ProjectsApi* | [**get_projects_api_v1_projects_get**](docs/ProjectsApi.md#get_projects_api_v1_projects_get) | **GET** /api/v1/projects/ | Get Projects
*ProjectsApi* | [**get_recent_chats_api_v1_projects_recentchats_get**](docs/ProjectsApi.md#get_recent_chats_api_v1_projects_recentchats_get) | **GET** /api/v1/projects/recentchats | Get Recent Chats
*ProjectsApi* | [**get_recent_items_api_v1_projects_recentitems_get**](docs/ProjectsApi.md#get_recent_items_api_v1_projects_recentitems_get) | **GET** /api/v1/projects/recentitems | Get Recent Items
*ProjectsApi* | [**get_recent_projects_api_v1_projects_recentprojects_get**](docs/ProjectsApi.md#get_recent_projects_api_v1_projects_recentprojects_get) | **GET** /api/v1/projects/recentprojects | Get Recent Projects
*ProjectsApi* | [**join_project_api_v1_projects_invite_join_invite_link_id_post**](docs/ProjectsApi.md#join_project_api_v1_projects_invite_join_invite_link_id_post) | **POST** /api/v1/projects/invite/join/{invite_link_id} | Join Project
*ProjectsApi* | [**onboard_user_api_v1_projects_onboard_user_post**](docs/ProjectsApi.md#onboard_user_api_v1_projects_onboard_user_post) | **POST** /api/v1/projects/onboard-user | Onboard User
*ProjectsApi* | [**pin_expert_comment_api_v1_projects_project_id_channels_channel_id_messages_message_id_expert_comments_comment_id_pin_post**](docs/ProjectsApi.md#pin_expert_comment_api_v1_projects_project_id_channels_channel_id_messages_message_id_expert_comments_comment_id_pin_post) | **POST** /api/v1/projects/{project_id}/channels/{channel_id}/messages/{message_id}/expert-comments/{comment_id}/pin | Pin Expert Comment
*ProjectsApi* | [**remove_user_from_project_api_v1_projects_project_id_remove_user_target_account_id_delete**](docs/ProjectsApi.md#remove_user_from_project_api_v1_projects_project_id_remove_user_target_account_id_delete) | **DELETE** /api/v1/projects/{project_id}/remove-user/{target_account_id} | Remove User From Project
*ProjectsApi* | [**restore_project_api_v1_projects_project_id_restore_post**](docs/ProjectsApi.md#restore_project_api_v1_projects_project_id_restore_post) | **POST** /api/v1/projects/{project_id}/restore | Restore Project
*ProjectsApi* | [**trash_project_api_v1_projects_project_id_trash_post**](docs/ProjectsApi.md#trash_project_api_v1_projects_project_id_trash_post) | **POST** /api/v1/projects/{project_id}/trash | Trash Project
*ProjectsApi* | [**update_artifact_published_url_api_v1_projects_project_id_channels_channel_id_artifacts_artifact_id_artifact_url_put**](docs/ProjectsApi.md#update_artifact_published_url_api_v1_projects_project_id_channels_channel_id_artifacts_artifact_id_artifact_url_put) | **PUT** /api/v1/projects/{project_id}/channels/{channel_id}/artifacts/{artifact_id}/artifact_url | Update Artifact Published Url
*ProjectsApi* | [**update_channel_name_api_v1_projects_project_id_channels_channel_id_patch**](docs/ProjectsApi.md#update_channel_name_api_v1_projects_project_id_channels_channel_id_patch) | **PATCH** /api/v1/projects/{project_id}/channels/{channel_id} | Update the channel name
*ReadAIApi* | [**read_ai_webhook_api_v1_readai_webhook_ingest_account_id_read_ai_trigger_id_post**](docs/ReadAIApi.md#read_ai_webhook_api_v1_readai_webhook_ingest_account_id_read_ai_trigger_id_post) | **POST** /api/v1/readai/webhook/ingest/{account_id}/{read_ai_trigger_id} | Read Ai Webhook
*RecommendationApi* | [**get_influencers_profiles_api_v1_recommendation_influencers_profiles_post**](docs/RecommendationApi.md#get_influencers_profiles_api_v1_recommendation_influencers_profiles_post) | **POST** /api/v1/recommendation/influencers-profiles | Get Influencers Profiles
*RecommendationApi* | [**get_projects_with_feeds_api_v1_recommendation_projects_with_feeds_get**](docs/RecommendationApi.md#get_projects_with_feeds_api_v1_recommendation_projects_with_feeds_get) | **GET** /api/v1/recommendation/projects-with-feeds | Get Projects With Feeds
*RecommendationApi* | [**get_recommendation_api_v1_recommendation_feed_get**](docs/RecommendationApi.md#get_recommendation_api_v1_recommendation_feed_get) | **GET** /api/v1/recommendation/feed | Get Recommendation
*RecommendationApi* | [**get_recommendation_api_v1_recommendation_feed_post**](docs/RecommendationApi.md#get_recommendation_api_v1_recommendation_feed_post) | **POST** /api/v1/recommendation/feed | Get Recommendation
*RecommendationApi* | [**trigger_recommendation_workflow_api_v1_recommendation_cron_trigger_post**](docs/RecommendationApi.md#trigger_recommendation_workflow_api_v1_recommendation_cron_trigger_post) | **POST** /api/v1/recommendation/cron-trigger | Trigger Recommendation Workflow
*RedisApi* | [**get_bot_dispatch_session_api_v1_redis_botdispatch_session_get**](docs/RedisApi.md#get_bot_dispatch_session_api_v1_redis_botdispatch_session_get) | **GET** /api/v1/redis/botdispatch/session | Get Bot Dispatch Session
*RedisApi* | [**get_breadcrumbs_api_v1_redis_breadcrumbs_types_post**](docs/RedisApi.md#get_breadcrumbs_api_v1_redis_breadcrumbs_types_post) | **POST** /api/v1/redis/breadcrumbs/types | Get Breadcrumbs
*RedisApi* | [**set_bot_dispatch_session_api_v1_redis_botdispatch_session_post**](docs/RedisApi.md#set_bot_dispatch_session_api_v1_redis_botdispatch_session_post) | **POST** /api/v1/redis/botdispatch/session | Set Bot Dispatch Session
*RedisApi* | [**store_api_v1_redis_store_post**](docs/RedisApi.md#store_api_v1_redis_store_post) | **POST** /api/v1/redis/store | Store
*SearchApi* | [**search_api_v1_search_post**](docs/SearchApi.md#search_api_v1_search_post) | **POST** /api/v1/search/ | Search
*SecondBrainApi* | [**bot_dispatch_api_v1_second_brain_bot_dispatch_post**](docs/SecondBrainApi.md#bot_dispatch_api_v1_second_brain_bot_dispatch_post) | **POST** /api/v1/second-brain/bot-dispatch | Bot Dispatch
*SecondBrainApi* | [**bot_status_api_v1_second_brain_bot_status_get**](docs/SecondBrainApi.md#bot_status_api_v1_second_brain_bot_status_get) | **GET** /api/v1/second-brain/bot-status | Bot Status
*SecondBrainApi* | [**bot_stop_api_v1_second_brain_bot_stop_post**](docs/SecondBrainApi.md#bot_stop_api_v1_second_brain_bot_stop_post) | **POST** /api/v1/second-brain/bot-stop | Bot Stop
*SecondBrainApi* | [**delete_active_transcript_api_v1_second_brain_active_transcript_delete**](docs/SecondBrainApi.md#delete_active_transcript_api_v1_second_brain_active_transcript_delete) | **DELETE** /api/v1/second-brain/active-transcript | Delete Active Transcript
*SecondBrainApi* | [**delete_spovs_api_v1_second_brain_project_id_id_spovs_delete**](docs/SecondBrainApi.md#delete_spovs_api_v1_second_brain_project_id_id_spovs_delete) | **DELETE** /api/v1/second-brain/{project_id}/{id}/spovs | Delete Spovs
*SecondBrainApi* | [**extract_spovs_api_v1_second_brain_extract_spovs_post**](docs/SecondBrainApi.md#extract_spovs_api_v1_second_brain_extract_spovs_post) | **POST** /api/v1/second-brain/extract-spovs | Extract Spovs
*SecondBrainApi* | [**get_active_transcript_api_v1_second_brain_active_transcript_get**](docs/SecondBrainApi.md#get_active_transcript_api_v1_second_brain_active_transcript_get) | **GET** /api/v1/second-brain/active-transcript | Get Active Transcript
*SecondBrainApi* | [**get_latest_spov_api_v1_second_brain_project_id_spovs_get**](docs/SecondBrainApi.md#get_latest_spov_api_v1_second_brain_project_id_spovs_get) | **GET** /api/v1/second-brain/{project_id}/spovs | Get Latest Spov
*SecondBrainApi* | [**get_livekit_connection_api_v1_second_brain_livekit_connection_get**](docs/SecondBrainApi.md#get_livekit_connection_api_v1_second_brain_livekit_connection_get) | **GET** /api/v1/second-brain/livekit-connection | Get Livekit Connection
*SecondBrainApi* | [**get_transcripts_api_v1_second_brain_transcripts_get**](docs/SecondBrainApi.md#get_transcripts_api_v1_second_brain_transcripts_get) | **GET** /api/v1/second-brain/transcripts | Get Transcripts
*SecondBrainApi* | [**save_message_api_v1_second_brain_save_transcript_message_post**](docs/SecondBrainApi.md#save_message_api_v1_second_brain_save_transcript_message_post) | **POST** /api/v1/second-brain/save-transcript-message | Save Message
*SecondBrainApi* | [**save_spovs_api_v1_second_brain_spovs_post**](docs/SecondBrainApi.md#save_spovs_api_v1_second_brain_spovs_post) | **POST** /api/v1/second-brain/spovs | Save Spovs
*ArtifactsApi* | [**create_or_connect_sandbox_api_v1_interact_tasks_artifacts_sandbox_post_1**](docs/ArtifactsApi.md#create_or_connect_sandbox_api_v1_interact_tasks_artifacts_sandbox_post_1) | **POST** /api/v1/interact/tasks/artifacts/sandbox | Create Or Connect Sandbox
*ArtifactsApi* | [**execute_code_api_v1_interact_tasks_artifacts_execute_post_1**](docs/ArtifactsApi.md#execute_code_api_v1_interact_tasks_artifacts_execute_post_1) | **POST** /api/v1/interact/tasks/artifacts/execute | Execute Code
*ArtifactsApi* | [**generate_react_api_v1_interact_tasks_artifacts_generate_react_post_1**](docs/ArtifactsApi.md#generate_react_api_v1_interact_tasks_artifacts_generate_react_post_1) | **POST** /api/v1/interact/tasks/artifacts/generate/react | Generate React
*ArtifactsApi* | [**generate_streamlit_api_v1_interact_tasks_artifacts_generate_streamlit_post_1**](docs/ArtifactsApi.md#generate_streamlit_api_v1_interact_tasks_artifacts_generate_streamlit_post_1) | **POST** /api/v1/interact/tasks/artifacts/generate/streamlit | Generate Streamlit
*DefaultApi* | [**health_check_health_get**](docs/DefaultApi.md#health_check_health_get) | **GET** /health | Health Check
*GenerateApi* | [**generate_react_api_v1_interact_tasks_artifacts_generate_react_post_2**](docs/GenerateApi.md#generate_react_api_v1_interact_tasks_artifacts_generate_react_post_2) | **POST** /api/v1/interact/tasks/artifacts/generate/react | Generate React
*GenerateApi* | [**generate_streamlit_api_v1_interact_tasks_artifacts_generate_streamlit_post_2**](docs/GenerateApi.md#generate_streamlit_api_v1_interact_tasks_artifacts_generate_streamlit_post_2) | **POST** /api/v1/interact/tasks/artifacts/generate/streamlit | Generate Streamlit
*IngestApi* | [**get_indexing_stats_api_v1_library_ingest_stats_namespace_get_0**](docs/IngestApi.md#get_indexing_stats_api_v1_library_ingest_stats_namespace_get_0) | **GET** /api/v1/library/ingest/stats/{namespace} | Get Indexing Stats
*IngestApi* | [**ingest_documents_api_v1_library_ingest_post_0**](docs/IngestApi.md#ingest_documents_api_v1_library_ingest_post_0) | **POST** /api/v1/library/ingest/ | Ingest Documents
*IngestApi* | [**ingest_local_file_api_v1_library_ingest_local_file_post_0**](docs/IngestApi.md#ingest_local_file_api_v1_library_ingest_local_file_post_0) | **POST** /api/v1/library/ingest/local-file | Ingest Local File
*IngestApi* | [**ingest_video_api_v1_library_ingest_video_post_0**](docs/IngestApi.md#ingest_video_api_v1_library_ingest_video_post_0) | **POST** /api/v1/library/ingest/video | Ingest Video
*IngestApi* | [**refresh_workflowy_nodes_api_v1_library_ingest_workflowy_refresh_post_0**](docs/IngestApi.md#refresh_workflowy_nodes_api_v1_library_ingest_workflowy_refresh_post_0) | **POST** /api/v1/library/ingest/workflowy/refresh | Refresh Workflowy Nodes
*IngestApi* | [**scrape_and_ingest_workflowy_api_v1_library_ingest_workflowy_post_0**](docs/IngestApi.md#scrape_and_ingest_workflowy_api_v1_library_ingest_workflowy_post_0) | **POST** /api/v1/library/ingest/workflowy | Scrape And Ingest Workflowy
*RetrieveApi* | [**retrieve_documents_api_v1_library_retrieve_post_0**](docs/RetrieveApi.md#retrieve_documents_api_v1_library_retrieve_post_0) | **POST** /api/v1/library/retrieve/ | Retrieve Documents
*TasksApi* | [**create_or_connect_sandbox_api_v1_interact_tasks_artifacts_sandbox_post_0**](docs/TasksApi.md#create_or_connect_sandbox_api_v1_interact_tasks_artifacts_sandbox_post_0) | **POST** /api/v1/interact/tasks/artifacts/sandbox | Create Or Connect Sandbox
*TasksApi* | [**execute_code_api_v1_interact_tasks_artifacts_execute_post_0**](docs/TasksApi.md#execute_code_api_v1_interact_tasks_artifacts_execute_post_0) | **POST** /api/v1/interact/tasks/artifacts/execute | Execute Code
*TasksApi* | [**generate_react_api_v1_interact_tasks_artifacts_generate_react_post_0**](docs/TasksApi.md#generate_react_api_v1_interact_tasks_artifacts_generate_react_post_0) | **POST** /api/v1/interact/tasks/artifacts/generate/react | Generate React
*TasksApi* | [**generate_streamlit_api_v1_interact_tasks_artifacts_generate_streamlit_post_0**](docs/TasksApi.md#generate_streamlit_api_v1_interact_tasks_artifacts_generate_streamlit_post_0) | **POST** /api/v1/interact/tasks/artifacts/generate/streamlit | Generate Streamlit
*TasksApi* | [**text_qna_api_v1_interact_tasks_text_post_0**](docs/TasksApi.md#text_qna_api_v1_interact_tasks_text_post_0) | **POST** /api/v1/interact/tasks/text/ | Text Qna
*TextApi* | [**text_qna_api_v1_interact_tasks_text_post_1**](docs/TextApi.md#text_qna_api_v1_interact_tasks_text_post_1) | **POST** /api/v1/interact/tasks/text/ | Text Qna


## Documentation For Models

 - [Account](docs/Account.md)
 - [AccountIdResponse](docs/AccountIdResponse.md)
 - [Artifact](docs/Artifact.md)
 - [Attachment](docs/Attachment.md)
 - [AttachmentDownloadResponse](docs/AttachmentDownloadResponse.md)
 - [AttachmentUploadRequest](docs/AttachmentUploadRequest.md)
 - [AttachmentUploadResponse](docs/AttachmentUploadResponse.md)
 - [AuthResponse](docs/AuthResponse.md)
 - [AuthorizeGoogleResponse](docs/AuthorizeGoogleResponse.md)
 - [BodyAddWebcrawlingRequestApiV1CrawlNewPost](docs/BodyAddWebcrawlingRequestApiV1CrawlNewPost.md)
 - [BodyExportDataApiV1ProjectsProjectIdExportPost](docs/BodyExportDataApiV1ProjectsProjectIdExportPost.md)
 - [BotDispatchRequest](docs/BotDispatchRequest.md)
 - [BotStopRequest](docs/BotStopRequest.md)
 - [BreadcrumbActivityType](docs/BreadcrumbActivityType.md)
 - [BreadcrumbRequest](docs/BreadcrumbRequest.md)
 - [Channel](docs/Channel.md)
 - [ChannelCreate](docs/ChannelCreate.md)
 - [ChannelMessage](docs/ChannelMessage.md)
 - [ChannelState](docs/ChannelState.md)
 - [ChannelUpdate](docs/ChannelUpdate.md)
 - [CodeExecutionRequest](docs/CodeExecutionRequest.md)
 - [CodeExecutionResponse](docs/CodeExecutionResponse.md)
 - [CollectionItem](docs/CollectionItem.md)
 - [Command](docs/Command.md)
 - [CommandParameter](docs/CommandParameter.md)
 - [CommandStep](docs/CommandStep.md)
 - [Comment](docs/Comment.md)
 - [CompareRequest](docs/CompareRequest.md)
 - [ConversationInput](docs/ConversationInput.md)
 - [ConversationOutput](docs/ConversationOutput.md)
 - [CrawlResponse](docs/CrawlResponse.md)
 - [CreateChannel200Response](docs/CreateChannel200Response.md)
 - [CreateFeedbackRequest](docs/CreateFeedbackRequest.md)
 - [ExpertComment](docs/ExpertComment.md)
 - [FeedbackResponse](docs/FeedbackResponse.md)
 - [GenerateSimpleTextRequest](docs/GenerateSimpleTextRequest.md)
 - [HTTPValidationError](docs/HTTPValidationError.md)
 - [IngestLocalFileRequest](docs/IngestLocalFileRequest.md)
 - [IngestRequest](docs/IngestRequest.md)
 - [IngestResponse](docs/IngestResponse.md)
 - [IngestStats](docs/IngestStats.md)
 - [IngestVideoRequest](docs/IngestVideoRequest.md)
 - [Integration](docs/Integration.md)
 - [InteractRequest](docs/InteractRequest.md)
 - [LibraryInput](docs/LibraryInput.md)
 - [LibraryItem](docs/LibraryItem.md)
 - [LibraryItemResponse](docs/LibraryItemResponse.md)
 - [LibraryOutput](docs/LibraryOutput.md)
 - [LibraryResponse](docs/LibraryResponse.md)
 - [LiveKitConnectionResponse](docs/LiveKitConnectionResponse.md)
 - [ManifestItem](docs/ManifestItem.md)
 - [Message](docs/Message.md)
 - [MessageExpertSummary](docs/MessageExpertSummary.md)
 - [OauthStatusResponse](docs/OauthStatusResponse.md)
 - [Project](docs/Project.md)
 - [ProjectAddUserResponse](docs/ProjectAddUserResponse.md)
 - [ProjectCreate](docs/ProjectCreate.md)
 - [ProjectDetailResponseInput](docs/ProjectDetailResponseInput.md)
 - [ProjectDetailResponseOutput](docs/ProjectDetailResponseOutput.md)
 - [ProjectListResponse](docs/ProjectListResponse.md)
 - [ProjectOnboardResponse](docs/ProjectOnboardResponse.md)
 - [ProjectRemoveUserResponse](docs/ProjectRemoveUserResponse.md)
 - [ProjectResponse](docs/ProjectResponse.md)
 - [ProjectSimpleResponse](docs/ProjectSimpleResponse.md)
 - [ProjectUpdate](docs/ProjectUpdate.md)
 - [ProjectWithFeed](docs/ProjectWithFeed.md)
 - [PublicAccountInfo](docs/PublicAccountInfo.md)
 - [RecentChat](docs/RecentChat.md)
 - [RecentItemsResponse](docs/RecentItemsResponse.md)
 - [RedisData](docs/RedisData.md)
 - [RefreshResponse](docs/RefreshResponse.md)
 - [RetrieveRequest](docs/RetrieveRequest.md)
 - [RetrieveResponse](docs/RetrieveResponse.md)
 - [RetrieveResult](docs/RetrieveResult.md)
 - [SandboxRequest](docs/SandboxRequest.md)
 - [SandboxResponse](docs/SandboxResponse.md)
 - [SearchRequest](docs/SearchRequest.md)
 - [SecondBrainInput](docs/SecondBrainInput.md)
 - [SecondBrainLinkRequest](docs/SecondBrainLinkRequest.md)
 - [SecondBrainNodeInput](docs/SecondBrainNodeInput.md)
 - [SecondBrainNodeOutput](docs/SecondBrainNodeOutput.md)
 - [SecondBrainOutput](docs/SecondBrainOutput.md)
 - [SecondBrainSource](docs/SecondBrainSource.md)
 - [SecondBrainSourceType](docs/SecondBrainSourceType.md)
 - [Source](docs/Source.md)
 - [Spov](docs/Spov.md)
 - [SpovType](docs/SpovType.md)
 - [Transcript](docs/Transcript.md)
 - [TranscriptMessage](docs/TranscriptMessage.md)
 - [UpdateDocumentRequest](docs/UpdateDocumentRequest.md)
 - [UserSearchResult](docs/UserSearchResult.md)
 - [ValidationError](docs/ValidationError.md)
 - [ValidationErrorLocInner](docs/ValidationErrorLocInner.md)
 - [WorkflowyRefreshRequest](docs/WorkflowyRefreshRequest.md)
 - [WorkflowySecretLinkRequest](docs/WorkflowySecretLinkRequest.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="APIKeyHeader"></a>
### APIKeyHeader

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author




